==> qtquick3d-6.10.1-2.gpkg.tar: image/usr/src/debug/dev-qt/qtquick3d-6.10.1/qtquick3d-everywhere-src-6.10.1_build/tools/materialeditor/.qt/rcc/qrc_PREFIX.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qtquickcontrols2.conf
  0x0,0x0,0x0,0x83,
  0x5b,
  0x43,0x6f,0x6e,0x74,0x72,0x6f,0x6c,0x73,0x5d,0xa,0x53,0x74,0x79,0x6c,0x65,0x3d,
  0x4d,0x61,0x74,0x65,0x72,0x69,0x61,0x6c,0xa,0xa,0x5b,0x4d,0x61,0x74,0x65,0x72,
  0x69,0x61,0x6c,0x5d,0xa,0x54,0x68,0x65,0x6d,0x65,0x3d,0x44,0x61,0x72,0x6b,0xa,
  0x41,0x63,0x63,0x65,0x6e,0x74,0x3d,0x50,0x75,0x72,0x70,0x6c,0x65,0xa,0x3b,0x20,
  0x46,0x6f,0x72,0x20,0x54,0x6f,0x6f,0x6c,0x42,0x61,0x72,0xa,0x50,0x72,0x69,0x6d,
  0x61,0x72,0x79,0x3d,0x23,0x34,0x32,0x34,0x32,0x34,0x32,0xa,0x56,0x61,0x72,0x69,
  0x61,0x6e,0x74,0x3d,0x44,0x65,0x6e,0x73,0x65,0xa,0xa,0x5b,0x55,0x6e,0x69,0x76,
  0x65,0x72,0x73,0x61,0x6c,0x5d,0xa,0x54,0x68,0x65,0x6d,0x65,0x3d,0x44,0x61,0x72,
  0x6b,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // qtquickcontrols2.conf
  0x0,0x15,
  0x8,0x1e,0x16,0x66,
  0x0,0x71,
  0x0,0x74,0x0,0x71,0x0,0x75,0x0,0x69,0x0,0x63,0x0,0x6b,0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x74,0x0,0x72,0x0,0x6f,0x0,0x6c,0x0,0x73,0x0,0x32,0x0,0x2e,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x66,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qtquickcontrols2.conf
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9a,0x7f,0xc,0x9f,0x48,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_PREFIX)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_PREFIX)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_PREFIX)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_PREFIX)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_PREFIX)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_PREFIX)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> qtquick3d-6.10.2-1.gpkg.tar: image/usr/src/debug/dev-qt/qtquick3d-6.10.2/qtquick3d-everywhere-src-6.10.2_build/tools/materialeditor/.qt/rcc/qrc_PREFIX.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qtquickcontrols2.conf
  0x0,0x0,0x0,0x83,
  0x5b,
  0x43,0x6f,0x6e,0x74,0x72,0x6f,0x6c,0x73,0x5d,0xa,0x53,0x74,0x79,0x6c,0x65,0x3d,
  0x4d,0x61,0x74,0x65,0x72,0x69,0x61,0x6c,0xa,0xa,0x5b,0x4d,0x61,0x74,0x65,0x72,
  0x69,0x61,0x6c,0x5d,0xa,0x54,0x68,0x65,0x6d,0x65,0x3d,0x44,0x61,0x72,0x6b,0xa,
  0x41,0x63,0x63,0x65,0x6e,0x74,0x3d,0x50,0x75,0x72,0x70,0x6c,0x65,0xa,0x3b,0x20,
  0x46,0x6f,0x72,0x20,0x54,0x6f,0x6f,0x6c,0x42,0x61,0x72,0xa,0x50,0x72,0x69,0x6d,
  0x61,0x72,0x79,0x3d,0x23,0x34,0x32,0x34,0x32,0x34,0x32,0xa,0x56,0x61,0x72,0x69,
  0x61,0x6e,0x74,0x3d,0x44,0x65,0x6e,0x73,0x65,0xa,0xa,0x5b,0x55,0x6e,0x69,0x76,
  0x65,0x72,0x73,0x61,0x6c,0x5d,0xa,0x54,0x68,0x65,0x6d,0x65,0x3d,0x44,0x61,0x72,
  0x6b,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // qtquickcontrols2.conf
  0x0,0x15,
  0x8,0x1e,0x16,0x66,
  0x0,0x71,
  0x0,0x74,0x0,0x71,0x0,0x75,0x0,0x69,0x0,0x63,0x0,0x6b,0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x74,0x0,0x72,0x0,0x6f,0x0,0x6c,0x0,0x73,0x0,0x32,0x0,0x2e,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x66,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qtquickcontrols2.conf
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9b,0xe7,0x71,0xb7,0x20,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_PREFIX)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_PREFIX)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_PREFIX)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_PREFIX)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_PREFIX)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_PREFIX)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
